headerbar button.titlebutton.close, .titlebar button.titlebutton.close {
  background-image: url("assets/close-normal.svg"); }

headerbar button.titlebutton.close:hover, .titlebar button.titlebutton.close:hover {
  background-image: url("assets/close-hover.svg"); }

headerbar button.titlebutton.close:active, .titlebar button.titlebutton.close:active {
  background-image: url("assets/close-active.svg"); }

headerbar button.titlebutton.close:backdrop, .titlebar button.titlebutton.close:backdrop {
  background-image: url("assets/close-backdrop-normal.svg"); }

headerbar button.titlebutton.close:backdrop:hover, .titlebar button.titlebutton.close:backdrop:hover {
  background-image: url("assets/close-backdrop-hover.svg"); }

headerbar button.titlebutton.close:backdrop:active, .titlebar button.titlebutton.close:backdrop:active {
  background-image: url("assets/close-backdrop-active.svg"); }

headerbar button.titlebutton.maximize, .titlebar button.titlebutton.maximize {
  background-image: url("assets/maximize-normal.svg"); }

headerbar button.titlebutton.maximize:hover, .titlebar button.titlebutton.maximize:hover {
  background-image: url("assets/maximize-hover.svg"); }

headerbar button.titlebutton.maximize:active, .titlebar button.titlebutton.maximize:active {
  background-image: url("assets/maximize-active.svg"); }

headerbar button.titlebutton.maximize:backdrop, .titlebar button.titlebutton.maximize:backdrop {
  background-image: url("assets/maximize-backdrop-normal.svg"); }

headerbar button.titlebutton.maximize:backdrop:hover, .titlebar button.titlebutton.maximize:backdrop:hover {
  background-image: url("assets/maximize-backdrop-hover.svg"); }

headerbar button.titlebutton.maximize:backdrop:active, .titlebar button.titlebutton.maximize:backdrop:active {
  background-image: url("assets/maximize-backdrop-active.svg"); }

headerbar button.titlebutton.minimize, .titlebar button.titlebutton.minimize {
  background-image: url("assets/minimize-normal.svg"); }

headerbar button.titlebutton.minimize:hover, .titlebar button.titlebutton.minimize:hover {
  background-image: url("assets/minimize-hover.svg"); }

headerbar button.titlebutton.minimize:active, .titlebar button.titlebutton.minimize:active {
  background-image: url("assets/minimize-active.svg"); }

headerbar button.titlebutton.minimize:backdrop, .titlebar button.titlebutton.minimize:backdrop {
  background-image: url("assets/minimize-backdrop-normal.svg"); }

headerbar button.titlebutton.minimize:backdrop:hover, .titlebar button.titlebutton.minimize:backdrop:hover {
  background-image: url("assets/minimize-backdrop-hover.svg"); }

headerbar button.titlebutton.minimize:backdrop:active, .titlebar button.titlebutton.minimize:backdrop:active {
  background-image: url("assets/minimize-backdrop-active.svg"); }

.maximized headerbar button.titlebutton.maximize, .maximized .titlebar button.titlebutton.maximize {
  background-image: url("assets/maximized-normal.svg"); }

.maximized headerbar button.titlebutton.maximize:hover, .maximized .titlebar button.titlebutton.maximize:hover {
  background-image: url("assets/maximized-hover.svg"); }

.maximized headerbar button.titlebutton.maximize:active, .maximized .titlebar button.titlebutton.maximize:active {
  background-image: url("assets/maximized-active.svg"); }

.maximized headerbar button.titlebutton.maximize:backdrop, .maximized .titlebar button.titlebutton.maximize:backdrop {
  background-image: url("assets/maximized-backdrop-normal.svg"); }

.maximized headerbar button.titlebutton.maximize:backdrop:hover, .maximized .titlebar button.titlebutton.maximize:backdrop:hover {
  background-image: url("assets/maximized-backdrop-hover.svg"); }

.maximized headerbar button.titlebutton.maximize:backdrop:active, .maximized .titlebar button.titlebutton.maximize:backdrop:active {
  background-image: url("assets/maximized-backdrop-active.svg"); }
